@@ -35,11 +35,11 @@ class AnyGroup(ABC):
         pass
 
     @abstractmethod
-    def add_group(self, group: "AnyGroup | str") -> "AnyGroup":
+    def add_group(self, group: "AnyGroup", alias: str | None = None) -> "AnyGroup":
         pass
 
     @abstractmethod
-    def add_task(self, task: AnyTask, alias: str | None = None) -> AnyTask:
+    def add_task(self, task: "AnyTask", alias: str | None = None) -> "AnyTask":
         pass
 
     @abstractmethod
@@ -55,5 +55,5 @@ class AnyGroup(ABC):
         pass
 
     @abstractmethod
-    def get_group_by_alias(self, name: str) -> "AnyGroup | None":
+    def get_group_by_alias(self, alias: str) -> "AnyGroup | None":
         pass
