@@ -124,31 +124,15 @@ async def summarize_history(
                 json.dumps(truncate_str(conversation_history.history, 1000)),
                 as_code=True,
             ),
-            make_prompt_section(
-                "Notes",
-                "\n".join(
-                    [
-                        make_prompt_section(
-                            "Long Term",
-                            conversation_history.long_term_note,
-                            as_code=True,
-                        ),
-                        make_prompt_section(
-                            "Contextual",
-                            conversation_history.contextual_note,
-                            as_code=True,
-                        ),
-                    ]
-                ),
-            ),
         ]
     )
-    summarization_agent = Agent(
+    summarize = create_history_summarization_tool(conversation_history)
+    summarization_agent = Agent[None, str](
         model=model,
+        output_type=summarize,
         system_prompt=system_prompt,
         model_settings=settings,
         retries=retries,
-        tools=[create_history_summarization_tool(conversation_history)],
     )
     try:
         ctx.print(stylize_faint("  📝 Rollup Conversation"), plain=True)
