@@ -5,10 +5,8 @@ from datetime import datetime, timezone
 from typing import TYPE_CHECKING, Any, Callable
 
 from zrb.attr.type import StrAttr, StrListAttr
-from zrb.config.config import CFG
 from zrb.config.llm_config import llm_config
 from zrb.config.llm_context.config import llm_context_config
-from zrb.config.llm_context.workflow import LLMWorkflow
 from zrb.config.llm_rate_limitter import llm_rate_limitter
 from zrb.context.any_context import AnyContext
 from zrb.context.any_shared_context import AnySharedContext
@@ -77,7 +75,6 @@ def get_workflow_names(
     ctx: AnyContext,
     workflows_attr: StrListAttr | None,
     render_workflows: bool,
-    user_message: str,
 ) -> list[str]:
     """Gets the workflows, prioritizing task-specific, then default."""
     raw_workflows = get_str_list_attr(
@@ -87,20 +84,7 @@ def get_workflow_names(
     )
     if raw_workflows is not None and len(raw_workflows) > 0:
         return [w.strip().lower() for w in raw_workflows if w.strip() != ""]
-
-    # Auto select workflows
-    available_workflows = get_available_workflows()
-    selected_workflows = {}
-    for workflow_name, workflow in available_workflows.items():
-        if workflow.default:
-            selected_workflows[workflow_name] = workflow
-        if workflow.when:
-            if re.search(workflow.when, user_message, re.IGNORECASE):
-                selected_workflows[workflow_name] = workflow
-
-    # Sort by priority
-    sorted_workflows = sorted(selected_workflows.values(), key=lambda w: w.priority)
-    return [w.name for w in sorted_workflows]
+    return []
 
 
 def get_project_context_prompt() -> str:
@@ -121,13 +105,13 @@ def get_workflow_prompt(
 ) -> str:
     available_workflows = get_available_workflows()
     active_workflow_names = set(
-        get_workflow_names(ctx, workflows_attr, render_workflows, user_message)
+        get_workflow_names(ctx, workflows_attr, render_workflows)
     )
-    available_workflow_prompts = []
     active_workflow_prompts = []
+    available_workflow_prompts = []
     for workflow_name, workflow in available_workflows.items():
         if workflow_name in active_workflow_names:
-            available_workflow_prompts.append(
+            active_workflow_prompts.append(
                 make_prompt_section(
                     workflow.name.capitalize(),
                     "\n".join(
@@ -140,7 +124,7 @@ def get_workflow_prompt(
                 )
             )
             continue
-        active_workflow_prompts.append(
+        available_workflow_prompts.append(
             make_prompt_section(
                 workflow.name.capitalize(),
                 "\n".join(
@@ -158,7 +142,7 @@ def get_workflow_prompt(
     if len(available_workflow_prompts) > 0:
         available_workflow_prompts = [
             "The following workflows are not automatically loaded.",
-            "Use `load workflow` tool to load necessary workflows based on your current task requirements.",
+            "Use `load workflow` tool to load necessary workflows based on your current task requirements.",  # noqa
         ] + available_workflow_prompts
     return "\n".join(
         [
@@ -455,7 +439,7 @@ def get_summarization_system_prompt(
 
 def get_attachments(
     ctx: AnyContext,
-    attachment: "UserContent | list[UserContent] | Callable[[AnySharedContext], UserContent | list[UserContent]] | None" = None,  # noqa
+    attachment: "UserContent | list[UserContent] | Callable[[AnyContext], UserContent | list[UserContent]] | None" = None,  # noqa
 ) -> "list[UserContent]":
     if attachment is None:
         return []
