@@ -9,18 +9,18 @@ from zrb.attr.type import (
     StrDictAttr,
     StrListAttr,
 )
-from zrb.context.any_shared_context import AnySharedContext
+from zrb.context.any_context import AnyContext
 from zrb.util.string.conversion import to_boolean
 
 
 def get_str_list_attr(
-    shared_ctx: AnySharedContext, attr: StrListAttr | None, auto_render: bool = True
+    ctx: AnyContext, attr: StrListAttr | None, auto_render: bool = True
 ) -> list[str]:
     """
     Retrieve a list of strings from shared context attributes.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (StrListAttr | None): The string list attribute to retrieve.
         auto_render (bool): Whether to auto-render the attribute values.
 
@@ -30,18 +30,18 @@ def get_str_list_attr(
     if attr is None:
         return []
     if callable(attr):
-        return attr(shared_ctx)
-    return [get_str_attr(shared_ctx, val, "", auto_render) for val in attr]
+        return attr(ctx)
+    return [get_str_attr(ctx, val, "", auto_render) for val in attr]
 
 
 def get_str_dict_attr(
-    shared_ctx: AnySharedContext, attr: StrDictAttr | None, auto_render: bool = True
+    ctx: AnyContext, attr: StrDictAttr | None, auto_render: bool = True
 ) -> dict[str, Any]:
     """
     Retrieve a dictionary of strings from shared context attributes.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (StrDictAttr | None): The string dictionary attribute to retrieve.
         auto_render (bool): Whether to auto-render the attribute values.
 
@@ -51,14 +51,12 @@ def get_str_dict_attr(
     if attr is None:
         return {}
     if callable(attr):
-        return attr(shared_ctx)
-    return {
-        key: get_str_attr(shared_ctx, val, "", auto_render) for key, val in attr.items()
-    }
+        return attr(ctx)
+    return {key: get_str_attr(ctx, val, "", auto_render) for key, val in attr.items()}
 
 
 def get_str_attr(
-    shared_ctx: AnySharedContext,
+    ctx: AnyContext,
     attr: StrAttr | None,
     default: StrAttr = "",
     auto_render: bool = True,
@@ -67,7 +65,7 @@ def get_str_attr(
     Retrieve a string from shared context attributes.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (StrAttr | None): The string attribute to retrieve.
         default (StrAttr): The default value if the attribute is None.
         auto_render (bool): Whether to auto-render the attribute value.
@@ -75,14 +73,14 @@ def get_str_attr(
     Returns:
         str: The string attribute value.
     """
-    val = get_attr(shared_ctx, attr, default, auto_render)
+    val = get_attr(ctx, attr, default, auto_render)
     if not isinstance(val, str):
         return str(val)
     return val
 
 
 def get_bool_attr(
-    shared_ctx: AnySharedContext,
+    ctx: AnyContext,
     attr: BoolAttr | None,
     default: BoolAttr = False,
     auto_render: bool = True,
@@ -91,7 +89,7 @@ def get_bool_attr(
     Retrieve a boolean from shared context attributes.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (BoolAttr | None): The boolean attribute to retrieve.
         default (BoolAttr): The default value if the attribute is None.
         auto_render (bool): Whether to auto-render the attribute value if it's a string.
@@ -99,14 +97,16 @@ def get_bool_attr(
     Returns:
         bool: The boolean attribute value.
     """
-    val = get_attr(shared_ctx, attr, default, auto_render)
+    val = get_attr(ctx, attr, default, auto_render)
     if isinstance(val, bool):
         return val
+    if val is None:
+        return False
     return to_boolean(val)
 
 
 def get_int_attr(
-    shared_ctx: AnySharedContext,
+    ctx: AnyContext,
     attr: IntAttr | None,
     default: IntAttr = 0,
     auto_render: bool = True,
@@ -115,7 +115,7 @@ def get_int_attr(
     Retrieve an integer from shared context attributes.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (IntAttr | None): The integer attribute to retrieve.
         default (IntAttr): The default value if the attribute is None.
         auto_render (bool): Whether to auto-render the attribute value if it's a string.
@@ -123,14 +123,16 @@ def get_int_attr(
     Returns:
         int: The integer attribute value.
     """
-    val = get_attr(shared_ctx, attr, default, auto_render)
+    val = get_attr(ctx, attr, default, auto_render)
     if isinstance(val, int):
         return val
+    if val is None:
+        return 0
     return int(val)
 
 
 def get_float_attr(
-    shared_ctx: AnySharedContext,
+    ctx: AnyContext,
     attr: FloatAttr | None,
     default: FloatAttr = 0.0,
     auto_render: bool = True,
@@ -139,7 +141,7 @@ def get_float_attr(
     Retrieve a float from shared context attributes.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (FloatAttr | None): The float attribute to retrieve.
         default (FloatAttr): The default value if the attribute is None.
         auto_render (bool): Whether to auto-render the attribute value if it's a string.
@@ -147,14 +149,16 @@ def get_float_attr(
     Returns:
         float | None: The float attribute value.
     """
-    val = get_attr(shared_ctx, attr, default, auto_render)
+    val = get_attr(ctx, attr, default, auto_render)
     if isinstance(val, (int, float)):
         return val
+    if val is None:
+        return 0.0
     return float(val)
 
 
 def get_attr(
-    shared_ctx: AnySharedContext,
+    ctx: AnyContext,
     attr: AnyAttr,
     default: AnyAttr,
     auto_render: bool = True,
@@ -163,7 +167,7 @@ def get_attr(
     Retrieve an attribute value from shared context, handling callables and rendering.
 
     Args:
-        shared_ctx (AnySharedContext): The shared context object.
+        ctx (AnyContext): The shared context object.
         attr (AnyAttr): The attribute to retrieve. Can be a value, a callable,
             or a string to render.
         default (AnyAttr): The default value if the attribute is None.
@@ -174,10 +178,10 @@ def get_attr(
     """
     if attr is None:
         if callable(default):
-            return default(shared_ctx)
+            return default(ctx)
         return default
     if callable(attr):
-        return attr(shared_ctx)
+        return attr(ctx)
     if isinstance(attr, str) and auto_render:
-        return shared_ctx.render(attr)
+        return ctx.render(attr)
     return attr
